@@ -10,7 +10,7 @@ from converge import settings
 
 from apphelpers.loggers import api_logger
 
-if settings.get('HONEYBADGER_API_KEY'):
+if settings.get("HONEYBADGER_API_KEY"):
     from honeybadger import Honeybadger
     from honeybadger.utils import filter_dict
 
@@ -20,13 +20,15 @@ def phony(f):
 
 
 def raise_not_found_on_none(f):
-    if getattr(f, 'not_found_on_none', None) == True:
+    if getattr(f, "not_found_on_none", None) == True:
+
         @wraps(f)
         def wrapper(*ar, **kw):
             ret = f(*ar, **kw)
             if ret is None:
-                raise HTTPNotFound('four o four')
+                raise HTTPNotFound("four o four")
             return ret
+
         return wrapper
     return f
 
@@ -36,6 +38,7 @@ def honeybadger_wrapper(hb):
     wrapper that executes the function in a try/except
     If an exception occurs, it is first reported to Honeybadger
     """
+
     def wrapper(f):
         @wraps(f)
         def f_wrapped(*args, **kw):
@@ -46,52 +49,54 @@ def honeybadger_wrapper(hb):
                     hb.notify(
                         e,
                         context={
-                            'func': f.__name__,
-                            'args': args,
-                            'kwargs': filter_dict(kw, settings.HB_PARAM_FILTERS)
-                        }
+                            "func": f.__name__,
+                            "args": args,
+                            "kwargs": filter_dict(kw, settings.HB_PARAM_FILTERS),
+                        },
                     )
                 finally:
                     raise e
             return ret
+
         return f_wrapped
+
     return wrapper
 
 
 @hug.directive()
 def user_id(default=None, request=None, **kwargs):
-    return request.context['user'].id
+    return request.context["user"].id
 
 
 @hug.directive()
 def user_name(default=None, request=None, **kwargs):
-    return request.context['user'].name
+    return request.context["user"].name
 
 
 @hug.directive()
 def user_email(default=None, request=None, **kwargs):
-    return request.context['user'].email
+    return request.context["user"].email
 
 
 @hug.directive()
 def domain(default=None, request=None, **kwargs):
-    return request.headers['HOST']
+    return request.headers["HOST"]
 
 
 @hug.directive()
 def user_mobile(default=None, request=None, **kwargs):
-    return request.context['user'].mobile
+    return request.context["user"].mobile
 
 
 @dataclass
 class User:
-    sid: str=None
-    id: int=None
-    name: str=None
-    groups: tuple=()
-    email: str=None
-    mobile: str=None
-    site_groups: dict=None
+    sid: str = None
+    id: int = None
+    name: str = None
+    groups: tuple = ()
+    email: str = None
+    mobile: str = None
+    site_groups: dict = None
 
     def to_dict(self):
         return asdict(self)
@@ -101,68 +106,81 @@ class User:
 
 
 def setup_strict_context_setter(sessions):
-
     def set_context(token):
 
-        uid, groups, name, email, mobile, site_groups = None, [], '', None, None, {}
+        uid, groups, name, email, mobile, site_groups = None, [], "", None, None, {}
 
         if token:
             try:
                 session = sessions.get(
-                    token,
-                    ['uid', 'name', 'groups', 'email', 'mobile', 'site_groups']
+                    token, ["uid", "name", "groups", "email", "mobile", "site_groups"]
                 )
                 uid, name, groups, email, mobile, site_groups = (
-                    session['uid'], session['name'], session['groups'],
-                    session['email'], session['mobile'], session['site_groups']
+                    session["uid"],
+                    session["name"],
+                    session["groups"],
+                    session["email"],
+                    session["mobile"],
+                    session["site_groups"],
                 )
             except InvalidSessionError:
-                raise HTTPUnauthorized('Invalid or expired session')
+                raise HTTPUnauthorized("Invalid or expired session")
 
         return User(
-            sid=token, id=uid, name=name, groups=groups,
-            email=email, mobile=mobile, site_groups=site_groups
+            sid=token,
+            id=uid,
+            name=name,
+            groups=groups,
+            email=email,
+            mobile=mobile,
+            site_groups=site_groups,
         )
 
     return set_context
 
 
 def setup_context_setter(sessions):
-
     def set_context(response, request, context, module):
         """
         Only sets context based on session.
         Does not raise any error
         """
-        uid, groups, name, email, mobile, site_groups = None, [], '', None, None, {}
-        token = request.get_header('Authorization')
+        uid, groups, name, email, mobile, site_groups = None, [], "", None, None, {}
+        token = request.get_header("Authorization")
         if token:
             try:
                 session = sessions.get(
-                    token,
-                    ['uid', 'name', 'groups', 'email', 'mobile', 'site_groups']
+                    token, ["uid", "name", "groups", "email", "mobile", "site_groups"]
                 )
                 uid, name, groups, email, mobile, site_groups = (
-                    session['uid'], session['name'], session['groups'],
-                    session['email'], session['mobile'], session['site_groups']
+                    session["uid"],
+                    session["name"],
+                    session["groups"],
+                    session["email"],
+                    session["mobile"],
+                    session["site_groups"],
                 )
                 if api_logger:
-                    api_logger.info('{} | {} | {}',
-                                    uid, request.method, request.url)
+                    api_logger.info("{} | {} | {}", uid, request.method, request.url)
 
             except InvalidSessionError:
                 pass
 
-        request.context['user'] = User(
-            sid=token, id=uid, name=name, groups=groups,
-            email=email, mobile=mobile, site_groups=site_groups
+        request.context["user"] = User(
+            sid=token,
+            id=uid,
+            name=name,
+            groups=groups,
+            email=email,
+            mobile=mobile,
+            site_groups=site_groups,
         )
+
     return set_context
 
 
 class APIFactory:
-
-    def __init__(self, router, urls_prefix=''):
+    def __init__(self, router, urls_prefix=""):
         self.router = router
         self.db_tr_wrapper = phony
         self.access_wrapper = phony
@@ -199,41 +217,44 @@ class APIFactory:
         set_context = setup_context_setter(self.sessions)
         self.router = self.router.http(requires=set_context)
         set_context = setup_strict_context_setter(self.sessions)
-        self.secure_router = self.router.http(requires=hug.authentication.token(set_context))
+        self.secure_router = self.router.http(
+            requires=hug.authentication.token(set_context)
+        )
 
         def access_wrapper(f):
             """
             This is the authentication + authorization part
             """
-            login_required = getattr(f, 'login_required', None)
-            groups_required = getattr(f, 'groups_required', None)
-            groups_forbidden = getattr(f, 'groups_forbidden', None)
-            authorizer = getattr(f, 'authorizer', None)
+            login_required = getattr(f, "login_required", None)
+            groups_required = getattr(f, "groups_required", None)
+            groups_forbidden = getattr(f, "groups_forbidden", None)
+            authorizer = getattr(f, "authorizer", None)
 
             if login_required or groups_required or groups_forbidden or authorizer:
 
                 @wraps(f)
                 def wrapper(request, *args, **kw):
 
-                    user = request.context['user']
+                    user = request.context["user"]
 
                     # this is authentication part
                     if not user.id:
-                        raise HTTPUnauthorized('Invalid or expired session')
+                        raise HTTPUnauthorized("Invalid or expired session")
 
                     # this is authorization part
                     groups = set(user.groups)
 
                     if groups_required and not groups.intersection(groups_required):
-                        raise HTTPForbidden('Unauthorized access')
+                        raise HTTPForbidden("Unauthorized access")
 
                     if groups_forbidden and groups.intersection(groups_forbidden):
-                        raise HTTPForbidden('Unauthorized access')
+                        raise HTTPForbidden("Unauthorized access")
 
                     if authorizer and not authorizer(user, *args, **kw):
-                        raise HTTPForbidden('Unauthorized access')
+                        raise HTTPForbidden("Unauthorized access")
 
                     return f(*args, **kw)
+
             else:
                 wrapper = f
 
@@ -243,21 +264,21 @@ class APIFactory:
             """
             This is the authentication + authorization part
             """
-            login_required = getattr(f, 'login_required', None)
-            groups_required = getattr(f, 'groups_required', None)
-            groups_forbidden = getattr(f, 'groups_forbidden', None)
-            authorizer = getattr(f, 'authorizer', None)
+            login_required = getattr(f, "login_required", None)
+            groups_required = getattr(f, "groups_required", None)
+            groups_forbidden = getattr(f, "groups_forbidden", None)
+            authorizer = getattr(f, "authorizer", None)
 
             if login_required or groups_required or groups_forbidden or authorizer:
 
                 @wraps(f)
                 def wrapper(request, *args, **kw):
 
-                    user = request.context['user']
+                    user = request.context["user"]
 
                     # this is authentication part
                     if not user.id:
-                        raise HTTPUnauthorized('Invalid or expired session')
+                        raise HTTPUnauthorized("Invalid or expired session")
 
                     # this is authorization part
                     groups = set(user.groups)
@@ -266,13 +287,13 @@ class APIFactory:
                         groups = groups.union(user.site_groups.get(site_id, []))
 
                     if groups_required and not groups.intersection(groups_required):
-                        raise HTTPForbidden('Unauthorized access')
+                        raise HTTPForbidden("Unauthorized access")
 
                     if groups_forbidden and groups.intersection(groups_forbidden):
-                        raise HTTPForbidden('Unauthorized access')
+                        raise HTTPForbidden("Unauthorized access")
 
                     if authorizer and not authorizer(user, *args, **kw):
-                        raise HTTPForbidden('Unauthorized access')
+                        raise HTTPForbidden("Unauthorized access")
 
                     return f(*args, **kw)
 
@@ -281,19 +302,22 @@ class APIFactory:
 
             return wrapper
 
-        self.access_wrapper = multisite_access_wrapper if self.multi_site_enabled else access_wrapper
+        self.access_wrapper = (
+            multisite_access_wrapper if self.multi_site_enabled else access_wrapper
+        )
 
     def choose_router(self, f):
-        login_required = hasattr(f, 'login_required') and f.login_required
+        login_required = hasattr(f, "login_required") and f.login_required
         return self.secure_router if login_required else self.router
 
     def build(self, method, method_args, method_kw, f):
-        print(f'{method_args[0]} [{method.__name__.upper()}] => {f.__module__}:{f.__name__}')
+        print(
+            f"{method_args[0]} [{method.__name__.upper()}] => {f.__module__}:{f.__name__}"
+        )
         m = method(*method_args, **method_kw)
         f = self.access_wrapper(
-            self.honeybadger_wrapper(
-                self.db_tr_wrapper(
-                    raise_not_found_on_none(f))))
+            self.honeybadger_wrapper(self.db_tr_wrapper(raise_not_found_on_none(f)))
+        )
         # NOTE: ^ wrapper ordering is important. access_wrapper needs request which
         # others don't. If access_wrapper comes late in the order it won't be passed
         # request parameter.
@@ -302,45 +326,57 @@ class APIFactory:
     def get(self, path, *a, **k):
         def _wrapper(f):
             router = self.choose_router(f)
-            args = (path if path.startswith('/') else (self.urls_prefix + path),) + a
+            args = (path if path.startswith("/") else (self.urls_prefix + path),) + a
             return self.build(router.get, args, k, f)
+
         return _wrapper
 
     def post(self, path, *a, **k):
         def _wrapper(f):
             router = self.choose_router(f)
-            args = (path if path.startswith('/') else (self.urls_prefix + path),) + a
+            args = (path if path.startswith("/") else (self.urls_prefix + path),) + a
             return self.build(router.post, args, k, f)
+
         return _wrapper
 
     def put(self, path, *a, **k):
         def _wrapper(f):
             router = self.choose_router(f)
-            args = (path if path.startswith('/') else (self.urls_prefix + path),) + a
+            args = (path if path.startswith("/") else (self.urls_prefix + path),) + a
             return self.build(router.put, args, k, f)
+
         return _wrapper
 
     def patch(self, path, *a, **k):
         def _wrapper(f):
             router = self.choose_router(f)
-            args = (path if path.startswith('/') else (self.urls_prefix + path),) + a
+            args = (path if path.startswith("/") else (self.urls_prefix + path),) + a
             return self.build(router.patch, args, k, f)
+
         return _wrapper
 
     def delete(self, path, *a, **k):
         def _wrapper(f):
             router = self.choose_router(f)
-            args = (path if path.startswith('/') else (self.urls_prefix + path),) + a
+            args = (path if path.startswith("/") else (self.urls_prefix + path),) + a
             return self.build(router.delete, args, k, f)
+
         return _wrapper
 
-    def map_resource(self, collection_url, resource=None, handlers=None, id_field='id'):
+    def map_resource(self, collection_url, resource=None, handlers=None, id_field="id"):
         if resource:
             raise NotImplementedError("Resource not supported yet")
 
-        resource_url = collection_url + '{' + id_field + '}'
+        resource_url = collection_url + "{" + id_field + "}"
         assert isinstance(handlers, (list, tuple)), "handlers should be list or tuple"
-        get_collection, add_resource, replace_resource, get_resource, update_resource, delete_resource = handlers
+        (
+            get_collection,
+            add_resource,
+            replace_resource,
+            get_resource,
+            update_resource,
+            delete_resource,
+        ) = handlers
 
         if get_collection:
             self.get(collection_url)(get_collection)
